@@ -20,7 +20,7 @@
 #include "xml-dir.h"
 #include "xml-entry.h"
 
-#include <gnome-xml/parser.h>
+#include <libxml/parser.h>
 
 #include <stdio.h>
 #include <time.h>
@@ -185,7 +185,12 @@ dir_load        (const gchar* key, const gchar* xml_root_dir, GError** err)
       }
     else
       {
-        dir_mode = mode_t_to_mode(s.st_mode);
+        /* Take directory mode from the xml_root_dir, if possible */
+        if (stat (xml_root_dir, &s) == 0)
+          {
+            dir_mode = mode_t_to_mode(s.st_mode);
+          }
+        
         file_mode = dir_mode & ~0111; /* turn off search bits */
       }
   }
@@ -347,6 +352,17 @@ dir_sync        (Dir* d, GError** err)
             }
         }
 
+      /* Set permissions on the new file */
+      if (chmod (tmp_filename, d->file_mode) != 0)
+        {
+          gconf_set_error(err, GCONF_ERROR_FAILED, 
+                          _("Failed to set mode on `%s': %s"),
+                          tmp_filename, strerror(errno));
+          
+          retval = FALSE;
+          goto failed_end_of_sync;
+        }
+      
       old_existed = gconf_file_exists(d->xml_filename);
 
       if (old_existed)
@@ -959,9 +975,11 @@ dir_fill_cache_from_doc(Dir* d)
         }
       else
         {
-          gconf_log(GCL_WARNING,
-                     _("Toplevel node in XML file `%s' is not an <entry>, ignoring"),
-                     d->xml_filename);
+          if (node->type == XML_ELEMENT_NODE)
+            gconf_log(GCL_WARNING,
+                      _("A toplevel node in XML file `%s' is <%s> rather than <entry>, ignoring"),
+                      d->xml_filename,
+                      node->name ? (char*) node->name : "unknown");
         }
       
       node = node->next;
