@@ -20,8 +20,8 @@
 #include "xml-entry.h"
 #include <gconf/gconf-internals.h>
 #include <stdlib.h>
-#include <gnome-xml/entities.h>
-#include <gnome-xml/xmlmemory.h>
+#include <libxml/entities.h>
+#include <libxml/xmlmemory.h>
 
 static void
 entry_sync_if_needed(Entry* e, GConfValue* val);
@@ -197,7 +197,7 @@ entry_unset_value     (Entry        *e,
 
           if (error != NULL)
             {
-              gconf_log(GCL_WARNING, _("%s"), error->message);
+              gconf_log(GCL_WARNING, "%s", error->message);
               g_error_free(error);
               error = NULL;
             }
