@@ -479,7 +479,7 @@ main(int argc, char** argv)
   GError *err;
   char *lock_dir;
   char *gconfd_dir;
-  int replacement_fd;
+  int dev_null_fd;
   int write_byte_fd;
   
   /* Now this is an argument parser */
@@ -494,14 +494,16 @@ main(int argc, char** argv)
    * all messages to syslog
    */
 
-  replacement_fd = open ("/dev/null", O_RDONLY);
-  dup2 (0, replacement_fd);
-
-  replacement_fd = open ("/dev/null", O_WRONLY);
-  dup2 (1, replacement_fd);
-
-  replacement_fd = open ("/dev/null", O_WRONLY);
-  dup2 (2, replacement_fd);
+  if (!g_getenv ("GCONF_DEBUG_OUTPUT"))
+    {
+      dev_null_fd = open ("/dev/null", O_RDWR);
+      if (dev_null_fd >= 0)
+        {
+	  dup2 (dev_null_fd, 0);
+	  dup2 (dev_null_fd, 1);
+	  dup2 (dev_null_fd, 2);
+	}
+    }
   
   umask (022);
   
