@@ -22,9 +22,9 @@
 #include <stdio.h>
 #include <unistd.h>
 #include <popt.h>
-#include <gnome-xml/tree.h>
-#include <gnome-xml/parser.h>
-#include <gnome-xml/xmlmemory.h>
+#include <libxml/tree.h>
+#include <libxml/parser.h>
+#include <libxml/xmlmemory.h>
 #include <stdlib.h>
 #include <errno.h>
 
@@ -537,6 +537,16 @@ main (int argc, char** argv)
       else 
         return 2;
     }
+
+  /* Before creating engine */
+  if (default_source_mode)
+    {
+      const gchar** args = poptGetArgs(ctx);
+      if (do_get_default_source (conf, args)  == 1)
+        return 1;
+      else
+        return 0;
+    }
   
   if (makefile_install_mode)
     {
@@ -556,19 +566,11 @@ main (int argc, char** argv)
           /* Properly set, but set to nothing (use default source) */
           config_source = NULL;
         }
-      
-      if (gconf_ping_daemon())
-        {
-          /* Eventually you should be able to run gconfd as long as
-             you're installing to a different database from the one
-             it's using, but I don't trust the locking right now. */
-          fprintf(stderr, _("Shouldn't run gconfd while installing new schema files.\nUse gconftool --shutdown to shut down the daemon, most safely while no applications are running\n(though things theoretically work if apps are running).\n"));
-          return 1;
-        }
 
-      /* Race condition! gconfd could start up. But we do have locking
-         as a second line of defense. */
       use_local_source = TRUE;
+
+      /* shut down daemon, this is a race condition, but will usually work. */
+      gconf_shutdown_daemon (NULL);
     }
   
   if (config_source == NULL)
@@ -728,16 +730,6 @@ main (int argc, char** argv)
           return 1;
         }
     }
-
-  if (default_source_mode)
-    {
-      const gchar** args = poptGetArgs(ctx);
-      if (do_get_default_source(conf, args)  == 1)
-        {
-          gconf_engine_unref(conf);
-          return 1;
-        }
-    }
   
   if (all_entries_mode)
     {
